[cfe-commits] r70171 - /cfe/trunk/include/clang/Frontend/PCHBitCodes.h
Chris Lattner
sabre at nondot.org
Sun Apr 26 17:44:11 PDT 2009
Author: lattner
Date: Sun Apr 26 19:44:11 2009
New Revision: 70171
URL: http://llvm.org/viewvc/llvm-project?rev=70171&view=rev
Log:
fix a comment by starting stmts/exprs after types and decls.
Modified:
cfe/trunk/include/clang/Frontend/PCHBitCodes.h
Modified: cfe/trunk/include/clang/Frontend/PCHBitCodes.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Frontend/PCHBitCodes.h?rev=70171&r1=70170&r2=70171&view=diff
==============================================================================
--- cfe/trunk/include/clang/Frontend/PCHBitCodes.h (original)
+++ cfe/trunk/include/clang/Frontend/PCHBitCodes.h Sun Apr 26 19:44:11 2009
@@ -446,12 +446,12 @@
/// These constants describe the records that describe statements
/// or expressions. These records can occur within either the type
/// or declaration blocks, so they begin with record values of
/// 100. Each constant describes a record for a specific
/// statement or expression class in the AST.
enum StmtCode {
/// \brief A marker record that indicates that we are at the end
/// of an expression.
- STMT_STOP,
+ STMT_STOP = 50,
/// \brief A NULL expression.
STMT_NULL_PTR,
/// \brief A NullStmt record.
@@ -446,12 +446,12 @@
/// or expressions. These records can occur within either the type
/// or declaration blocks, so they begin with record values of
- /// 100. Each constant describes a record for a specific
+ /// 50. Each constant describes a record for a specific
/// statement or expression class in the AST.
enum StmtCode {
More information about the cfe-commits
mailing list